==> igniteui-angular-charts-17.3.0.tgz: package/esm5/lib/PositiveVolumeIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { PositiveVolumeIndexIndicatorStrategy } from "./PositiveVolumeIndexIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var PositiveVolumeIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PositiveVolumeIndexIndicator, _super);
    function PositiveVolumeIndexIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PositiveVolumeIndexIndicator.prototype.bc = function () {
        return new PositiveVolumeIndexIndicator();
    };
    PositiveVolumeIndexIndicator.prototype.get_y0 = function () {
        return new PositiveVolumeIndexIndicatorStrategy();
    };
    Object.defineProperty(PositiveVolumeIndexIndicator.prototype, "y0", {
        get: function () {
            return this.get_y0();
        },
        enumerable: false,
        configurable: true
    });
    PositiveVolumeIndexIndicator.prototype.get_zd = function () {
        return PositiveVolumeIndexIndicator.$;
    };
    Object.defineProperty(PositiveVolumeIndexIndicator.prototype, "zd", {
        get: function () {
            return this.get_zd();
        },
        enumerable: false,
        configurable: true
    });
    PositiveVolumeIndexIndicator.$t = markType(PositiveVolumeIndexIndicator, 'PositiveVolumeIndexIndicator', StrategyBasedIndicator.$);
    return PositiveVolumeIndexIndicator;
}(StrategyBasedIndicator));
export { PositiveVolumeIndexIndicator };

==> igniteui-angular-charts-18.0.0.tgz: package/esm5/lib/PositiveVolumeIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { PositiveVolumeIndexIndicatorStrategy } from "./PositiveVolumeIndexIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var PositiveVolumeIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PositiveVolumeIndexIndicator, _super);
    function PositiveVolumeIndexIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PositiveVolumeIndexIndicator.prototype.bb = function () {
        return new PositiveVolumeIndexIndicator();
    };
    PositiveVolumeIndexIndicator.prototype.get_aaa = function () {
        return new PositiveVolumeIndexIndicatorStrategy();
    };
    Object.defineProperty(PositiveVolumeIndexIndicator.prototype, "aaa", {
        get: function () {
            return this.get_aaa();
        },
        enumerable: false,
        configurable: true
    });
    PositiveVolumeIndexIndicator.prototype.get_aan = function () {
        return PositiveVolumeIndexIndicator.$;
    };
    Object.defineProperty(PositiveVolumeIndexIndicator.prototype, "aan", {
        get: function () {
            return this.get_aan();
        },
        enumerable: false,
        configurable: true
    });
    PositiveVolumeIndexIndicator.$t = markType(PositiveVolumeIndexIndicator, 'PositiveVolumeIndexIndicator', StrategyBasedIndicator.$);
    return PositiveVolumeIndexIndicator;
}(StrategyBasedIndicator));
export { PositiveVolumeIndexIndicator };
